@@ -5,10 +5,8 @@
 #'
 #' @param recipe A recipe object. The step will be added to the
 #'  sequence of operations for this recipe.
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
+#' @param ... One or more selector functions to choose variables
+#'  for this step. See [selections()] for more details.
 #' @param role Not used by this step since no new variables are
 #'  created.
 #' @param trained A logical to indicate if the quantities for
@@ -22,16 +20,11 @@
 #'  when [prep.recipe()] is run, some operations may not be able to be
 #'  conducted on new data (e.g. processing the outcome variable(s)).
 #'  Care should be taken when using `skip = TRUE` as it may affect
-#'  the computations for subsequent operations
+#'  the computations for subsequent operations.
 #' @param id A character string that is unique to this step to identify it.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `value` (the means).
+#' @template step-return
 #'
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept normalization_methods
+#' @family normalization steps
 #' @export
 #' @details Centering data means that the average of a variable is
 #'  subtracted from the data. `step_center` estimates the
@@ -39,6 +32,9 @@
 #'  argument of `prep.recipe`. `bake.recipe` then applies
 #'  the centering to new data sets using these means.
 #'
+#'  When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  selectors or variables selected) and `value` (the means) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -61,8 +57,6 @@
 #'
 #' tidy(center_trans, number = 1)
 #' tidy(center_obj, number = 1)
-#' @seealso [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_center <-
   function(recipe,
            ...,
@@ -103,7 +97,7 @@ step_center_new <-
 
 #' @export
 prep.step_center <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   means <-
@@ -136,8 +130,7 @@ print.step_center <-
   }
 
 
-#' @rdname step_center
-#' @param x A `step_center` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_center <- function(x, ...) {
   if (is_trained(x)) {
