@@ -4,17 +4,11 @@
 #'  step that will convert date data into one or more factor or
 #'  numeric variables.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables that will be used to create the new variables. The
-#'  selected variables should have class `Date` or
+#' @param ... One or more selector functions to choose variables
+#'  for this step. The selected variables should have class `Date` or
 #'  `POSIXct`. See [selections()] for more details.
-#'  For the `tidy` method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new variable columns created by the original variables
-#'  will be used as predictors in a model.
 #' @param features A character string that includes at least one
 #'  of the following values: `month`, `dow` (day of week),
 #'  `doy` (day of year), `week`, `month`,
@@ -36,20 +30,19 @@
 #' @param columns A character string of variables that will be
 #'  used as inputs. This field is a placeholder and will be
 #'  populated once [prep.recipe()] is used.
-#' @return For `step_date`, an updated version of recipe with
-#'  the new step added to the sequence of existing steps (if any).
-#'  For the `tidy` method, a tibble with columns `terms`
-#'  (the selectors or variables selected), `value` (the feature
-#'  names), and `ordinal` (a logical).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept model_specification
-#' @concept variable_encodings
-#' @concept dates
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `TRUE`.
+#' @template step-return
+#' @family dummy variable and encoding steps
 #' @export
-#' @details Unlike other steps, `step_date` does *not*
-#'  remove the original date variables. [step_rm()] can be
-#'  used for this purpose.
+#' @details Unlike some other steps, `step_date` does *not*
+#'  remove the original date variables by default. Set `keep_original_cols`
+#'  to `FALSE` to remove them.
+#'
+#'  When you [`tidy()`] this step, a tibble with columns `terms`
+#'  (the selectors or variables selected), `value` (the feature
+#'  names), and `ordinal` (a logical) is returned.
+#'
 #' @examples
 #' library(lubridate)
 #'
@@ -67,9 +60,6 @@
 #'
 #' tidy(date_rec, number = 1)
 #'
-#' @seealso [step_holiday()] [step_rm()]
-#'   [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_date <-
   function(recipe,
            ...,
@@ -80,6 +70,7 @@ step_date <-
            label = TRUE,
            ordinal = FALSE,
            columns = NULL,
+           keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("date")
   ) {
@@ -94,8 +85,8 @@ step_date <-
       "month")
   if (!is_tune(features) & !is_varying(features)) {
     if (!all(features %in% feat)) {
-      rlang::abort("Possible values of `features` should include: ",
-           paste0("'", feat, "'", collapse = ", "))
+      rlang::abort(paste0("Possible values of `features` should include: ",
+           paste0("'", feat, "'", collapse = ", ")))
     }
   }
   add_step(
@@ -109,6 +100,7 @@ step_date <-
       label = label,
       ordinal = ordinal,
       columns = columns,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -116,7 +108,8 @@ step_date <-
 }
 
 step_date_new <-
-  function(terms, role, trained, features, abbr, label, ordinal, columns, skip, id) {
+  function(terms, role, trained, features, abbr, label, ordinal, columns,
+           keep_original_cols, skip, id) {
     step(
       subclass = "date",
       terms = terms,
@@ -127,6 +120,7 @@ step_date_new <-
       label = label,
       ordinal = ordinal,
       columns = columns,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -135,7 +129,7 @@ step_date_new <-
 
 #' @export
 prep.step_date <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   date_data <- info[info$variable %in% col_names, ]
   if (any(date_data$type != "date"))
@@ -154,6 +148,7 @@ prep.step_date <- function(x, training, info = NULL, ...) {
     label = x$label,
     ordinal = x$ordinal,
     columns = col_names,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -248,6 +243,10 @@ bake.step_date <- function(object, new_data, ...) {
   names(date_values) <- new_names
 
   new_data <- bind_cols(new_data, date_values)
+  keep_original_cols <- get_keep_original_cols(object)
+  if (!keep_original_cols) {
+    new_data <- new_data[, !(colnames(new_data) %in% object$columns), drop = FALSE]
+  }
 
   if (!is_tibble(new_data)) {
     new_data <- as_tibble(new_data)
@@ -264,8 +263,7 @@ print.step_date <-
     invisible(x)
   }
 
-#' @rdname step_date
-#' @param x A `step_date` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_date <- function(x, ...) {
   if (is_trained(x)) {
