@@ -1,7 +1,7 @@
 #' Down-Sample a Data Set Based on a Factor Variable
 #'
 #' @description
-#' \if{html}{\figure{lifecycle-soft-deprecated.svg}{alt="lifecycle-soft-deprecated"}}
+#' `r lifecycle::badge("deprecated")`
 #'
 #' `step_downsample` is now available as `themis::step_downsample()`. This
 #'  function creates a *specification* of a recipe step that will remove
@@ -9,13 +9,6 @@
 #'  level equal.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variable is used to sample the data. See [selections()]
-#'  for more details. The selection should result in _single
-#'  factor variable_. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param column A character string of the variable name that will
 #'  be populated (eventually) by the `...` selectors.
 #' @param under_ratio A numeric value for the ratio of the
@@ -28,10 +21,7 @@
 #' @param target An integer that will be used to subsample. This
 #'  should not be set by the user and will be populated by `prep`.
 #' @param seed An integer that will be used as the seed when downsampling.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the variable used to sample.
+#' @template step-return
 #' @details
 #' Down-sampling is intended to be performed on the _training_ set alone. For
 #'  this reason, the default is `skip = TRUE`. It is advisable to use
@@ -59,32 +49,15 @@
 #'  option `skip = TRUE` so that the extra sampling is _not_
 #'  conducted outside of the training set.
 #'
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept subsampling
+#' @keywords internal
 #' @export
-#' @examples
-#' library(modeldata)
-#' data(okc)
-#'
-#' sort(table(okc$diet, useNA = "always"))
-#'
-#' ds_rec <- recipe( ~ ., data = okc) %>%
-#'   step_downsample(diet) %>%
-#'   prep(training = okc)
-#'
-#' table(bake(ds_rec, new_data = NULL)$diet, useNA = "always")
-#'
-#' # since `skip` defaults to TRUE, baking the step has no effect
-#' baked_okc <- bake(ds_rec, new_data = okc)
-#' table(baked_okc$diet, useNA = "always")
 
 step_downsample <-
   function(recipe, ...,  under_ratio = 1, ratio = NA, role = NA, trained = FALSE,
            column = NULL, target = NA, skip = TRUE,
            seed = sample.int(10^5, 1), id = rand_id("downsample")) {
 
-    lifecycle::deprecate_soft("0.1.13",
+    lifecycle::deprecate_stop("0.1.13",
                               "recipes::step_downsample()",
                               "themis::step_downsample()")
 
@@ -136,7 +109,7 @@ step_downsample_new <-
 
 #' @export
 prep.step_downsample <- function(x, training, info = NULL, ...) {
-  col_name <- eval_select_recipes(x$terms, training, info)
+  col_name <- recipes_eval_select(x$terms, training, info)
 
   if (length(col_name) != 1)
     rlang::abort("Please select a single factor variable.")
@@ -206,7 +179,7 @@ print.step_downsample <-
 #' @export
 tidy.step_downsample <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$column)
+    res <- tibble(terms = unname(x$column))
   }
   else {
     term_names <- sel2char(x$terms)
@@ -219,7 +192,7 @@ tidy.step_downsample <- function(x, ...) {
 # ------------------------------------------------------------------------------
 
 
-#' @rdname tunable.step
+#' @rdname tunable.recipe
 #' @export
 tunable.step_downsample <- function(x, ...) {
   tibble::tibble(
