@@ -4,23 +4,26 @@
 #'  be used on a recipe to show what predictors and outcome(s)
 #'  could be used.
 #'
-#' @param x A recipe object where all steps have been prepared.
+#' @param x A recipe object that has been prepared.
 #' @param ... Note currently used.
 #' @return A formula.
 #' @examples
 #'
-#' formula(recipe(Species + Sepal.Length ~ ., data = iris))
+#' formula(recipe(Species + Sepal.Length ~ ., data = iris) %>% prep())
 #'
 #' iris_rec <- recipe(Species ~ ., data = iris) %>%
 #'   step_center(all_numeric()) %>%
-#'   prep(training = iris)
+#'   prep()
 #' formula(iris_rec)
 #' @export
 formula.recipe <- function(x, ...) {
   if (!fully_trained(x))
-    stop("All steps in the recipe must be prepped before the ",
-         "formula can be computed.",
-         call. = FALSE)
+    rlang::abort(
+      paste0(
+      "The recipe must be prepped before the ",
+      "formula can be computed."
+      )
+    )
 
   x <- summary(x)
   x_vars <- x$variable[x$role == "predictor"]
