@@ -4,29 +4,18 @@
 #'  step that will create new columns that are interaction terms
 #'  between two or more variables.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
 #' @param terms A traditional R formula that contains interaction
-#'  terms. This can include `.` and selectors.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
+#'  terms. This can include `.` and selectors. See [selections()]
+#'  for more details, and consider using [tidyselect::starts_with()] when
+#'  dummy variables have been created.
 #' @param objects A list of `terms` objects for each
 #'  individual interaction.
 #' @param sep A character value used to delineate variables in an
 #'  interaction (e.g. `var1_x_var2` instead of the more
 #'  traditional `var1:var2`).
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the interaction effects.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept model_specification
+#' @template step-return
 #' @export
 #' @details `step_interact` can create interactions between
 #'  variables. It is primarily intended for **numeric data**;
@@ -55,38 +44,39 @@
 #'  you wanted an interaction with numeric column `z`, you could
 #'  create a set of specific interaction effects (e.g.
 #'  `x_2:z + x_3:z` and so on) or you could use
-#'  `starts_with("z_"):z`. When [prep()] evaluates this step,
-#'  `starts_with("z_")` resolves to `(x_2 + x_3 + x_4 + x_5 + x6)`
-#'  so that the formula is now `(x_2 + x_3 + x_4 + x_5 + x6):z` and
+#'  `starts_with("x_"):z`. When [prep()] evaluates this step,
+#'  `starts_with("x_")` resolves to `(x_2 + x_3 + x_4 + x_5 + x_6)`
+#'  so that the formula is now `(x_2 + x_3 + x_4 + x_5 + x_6):z` and
 #'  all two-way interactions are created.
-
+#'
+#' When you [`tidy()`] this step, a tibble with column `terms`
+#'  (the interaction effects) is returned.
 #' @examples
 #' library(modeldata)
-#' data(biomass)
+#' data(penguins)
+#' penguins <- penguins %>% na.omit()
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
-#'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#' rec <- recipe(flipper_length_mm ~., data = penguins)
 #'
 #' int_mod_1 <- rec %>%
-#'   step_interact(terms = ~ carbon:hydrogen)
+#'   step_interact(terms = ~ bill_depth_mm:bill_length_mm)
 #'
+#' # specify all dummy variables succinctly with `starts_with()`
 #' int_mod_2 <- rec %>%
-#'   step_interact(terms = ~ (matches("gen$") + sulfur)^2)
+#'   step_dummy(sex, species, island) %>%
+#'   step_interact(terms = ~ body_mass_g:starts_with("species"))
 #'
-#' int_mod_1 <- prep(int_mod_1, training = biomass_tr)
-#' int_mod_2 <- prep(int_mod_2, training = biomass_tr)
+#' int_mod_1 <- prep(int_mod_1, training = penguins)
+#' int_mod_2 <- prep(int_mod_2, training = penguins)
 #'
-#' dat_1 <- bake(int_mod_1, biomass_te)
-#' dat_2 <- bake(int_mod_2, biomass_te)
+#' dat_1 <- bake(int_mod_1, penguins)
+#' dat_2 <- bake(int_mod_2, penguins)
 #'
 #' names(dat_1)
 #' names(dat_2)
 #'
 #' tidy(int_mod_1, number = 1)
-#' tidy(int_mod_2, number = 1)
+#' tidy(int_mod_2, number = 2)
 
 step_interact <-
   function(recipe,
@@ -139,17 +129,17 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
   # Use formula environment as quosure env
   env <- rlang::f_env(x$terms)
 
-  eval_select_recipes_expr <- function(expr) {
-    # Wrap `expr` into a list-of-quos as `eval_select_recipes()` expects
+  recipes_eval_select_expr <- function(expr) {
+    # Wrap `expr` into a list-of-quos as `recipes_eval_select()` expects
     quo <- new_quosure(expr, env)
     quos <- list(quo)
-    eval_select_recipes(quos, data = training, info = info)
+    recipes_eval_select(quos, data = training, info = info)
   }
 
   ## Resolve the selectors to a expression containing an additive
   ## function of the variables
   if(length(form_sel) > 0) {
-    form_res <- map(form_sel, eval_select_recipes_expr)
+    form_res <- map(form_sel, recipes_eval_select_expr)
     form_res <- map(form_res, vec_2_expr)
     ## Subsitute the column names into the original interaction
     ## formula.
@@ -317,8 +307,7 @@ int_name <- function(x) {
 }
 
 
-#' @rdname step_interact
-#' @param x A `step_interact` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_interact <- function(x, ...) {
   res <- tibble(terms = vapply(x$objects, int_name, character(1)))
@@ -381,6 +370,8 @@ intersect_selectors <- c(
 
   "has_role",
   "all_predictors",
+  "all_numeric_predictors",
+  "all_nominal_predictors",
   "all_outcomes",
 
   "has_type",
