@@ -5,33 +5,26 @@
 #'  deviation of one and a mean of zero.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param means A named numeric vector of means. This is
 #'  `NULL` until computed by [prep.recipe()].
 #' @param sds A named numeric vector of standard deviations This
 #'  is `NULL` until computed by [prep.recipe()].
 #' @param na_rm A logical value indicating whether `NA`
 #'  values should be removed when computing the standard deviation and mean.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `value` (the
-#'  standard deviations and means), and `statistic` for the type of value.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept normalization_methods
+#' @template step-return
+#' @family normalization steps
 #' @export
 #' @details Centering data means that the average of a variable is subtracted
 #'  from the data. Scaling data means that the standard deviation of a variable
 #'  is divided out of the data. `step_normalize` estimates the variable standard
 #'  deviations and means from the data used in the `training` argument of
-#'  `prep.recipe`. `bake.recipe` then applies the scaling to new data sets using
+#'  `prep.recipe`. [`bake.recipe`] then applies the scaling to new data sets using
 #'  these estimates.
+#'
+#'  When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  selectors or variables selected), `value` (the standard deviations and
+#'  means), and `statistic` for the type of value is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -54,6 +47,15 @@
 #' tidy(norm_trans, number = 1)
 #' tidy(norm_obj, number = 1)
 #'
+#' # To keep the original variables in the output, use `step_mutate_at`:
+#' norm_keep_orig <- rec %>%
+#'   step_mutate_at(all_numeric_predictors(), fn = list(orig = ~.)) %>%
+#'   step_normalize(-contains("orig"), -all_outcomes())
+#'
+#' keep_orig_obj <- prep(norm_keep_orig, training = biomass_tr)
+#' keep_orig_te <- bake(keep_orig_obj, biomass_te)
+#' keep_orig_te
+#'
 step_normalize <-
   function(recipe,
            ...,
@@ -96,7 +98,7 @@ step_normalize_new <-
 
 #' @export
 prep.step_normalize <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -131,8 +133,7 @@ print.step_normalize <-
   }
 
 
-#' @rdname step_normalize
-#' @param x A `step_normalize` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_normalize <- function(x, ...) {
   if (is_trained(x)) {
