@@ -1,51 +1,32 @@
 #' PCA Signal Extraction
 #'
-#' `step_pca` creates a *specification* of a recipe step
-#'  that will convert numeric data into one or more principal
-#'  components.
+#' `step_pca` creates a *specification* of a recipe step that will convert
+#'  numeric data into one or more principal components.
 #'
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables will be used to compute the components. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new principal component columns created by the original
-#'  variables will be used as predictors in a model.
-#' @param num_comp The number of PCA components to retain as new
-#'  predictors. If `num_comp` is greater than the number of columns
-#'  or the number of possible components, a smaller value will be
-#'  used.
-#' @param threshold A fraction of the total variance that should
-#'  be covered by the components. For example, `threshold =
-#'  .75` means that `step_pca` should generate enough
-#'  components to capture 75\% of the variability in the variables.
-#'  Note: using this argument will override and resent any value
-#'  given to `num_comp`.
+#' @param role For model terms created by this step, what analysis role should
+#'  they be assigned? By default, the new columns created by this step from
+#'  the original variables will be used as _predictors_ in a model.
+#' @param num_comp The number of PCA components to retain as new predictors.
+#'  If `num_comp` is greater than the number of columns or the number of
+#'  possible components, a smaller value will be used.
+#' @param threshold A fraction of the total variance that should be covered by
+#'  the components. For example, `threshold = .75` means that `step_pca` should
+#'  generate enough components to capture 75 percent of the variability in the
+#'  variables. Note: using this argument will override and reset any value given
+#'  to `num_comp`.
 #' @param options A list of options to the default method for
-#'  [stats::prcomp()]. Argument defaults are set to
-#'  `retx = FALSE`, `center = FALSE`, `scale. =
-#'  FALSE`, and `tol = NULL`. **Note** that the argument
-#'  `x` should not be passed here (or at all).
-#' @param res The [stats::prcomp.default()] object is
-#'  stored here once this preprocessing step has be trained by
-#'  [prep.recipe()].
-#' @param prefix A character string that will be the prefix to the
-#'  resulting new variables. See notes below.
-#' @param type For the `tidy()` method, either "coef" (for the variable
-#'  loadings per component) or "variance" (how much variance does each component
-#'  account for).
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `value` (the
-#'  loading), and `component`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept pca
-#' @concept projection_methods
+#'  [stats::prcomp()]. Argument defaults are set to `retx = FALSE`, `center =
+#'  FALSE`, `scale. = FALSE`, and `tol = NULL`. **Note** that the argument `x`
+#'  should not be passed here (or at all).
+#' @param res The [stats::prcomp.default()] object is stored here once this
+#'  preprocessing step has be trained by [prep.recipe()].
+#' @param prefix A character string for the prefix of the resulting new
+#'  variables. See notes below.
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `FALSE`.
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details
 #' Principal component analysis (PCA) is a transformation of a
@@ -75,14 +56,17 @@
 #'  number of components that are required to capture a specified
 #'  fraction of the total variance in the variables.
 #'
+#' When you [`tidy()`] this step, use either `type = "coef"` for the variable
+#'  loadings per component or `type = "variance"` for how much variance each
+#'  component accounts for.
+#'
 #' @references Jolliffe, I. T. (2010). *Principal Component
 #'  Analysis*. Springer.
 #'
 #' @examples
 #' rec <- recipe( ~ ., data = USArrests)
 #' pca_trans <- rec %>%
-#'   step_center(all_numeric()) %>%
-#'   step_scale(all_numeric()) %>%
+#'   step_normalize(all_numeric()) %>%
 #'   step_pca(all_numeric(), num_comp = 3)
 #' pca_estimates <- prep(pca_trans, training = USArrests)
 #' pca_data <- bake(pca_estimates, USArrests)
@@ -92,17 +76,13 @@
 #'      xlim = rng, ylim = rng)
 #'
 #' with_thresh <- rec %>%
-#'   step_center(all_numeric()) %>%
-#'   step_scale(all_numeric()) %>%
+#'   step_normalize(all_numeric()) %>%
 #'   step_pca(all_numeric(), threshold = .99)
 #' with_thresh <- prep(with_thresh, training = USArrests)
 #' bake(with_thresh, USArrests)
 #'
-#' tidy(pca_trans, number = 3)
-#' tidy(pca_estimates, number = 3)
-#' @seealso [step_ica()] [step_kpca()]
-#'   [step_isomap()] [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
+#' tidy(pca_trans, number = 2)
+#' tidy(pca_estimates, number = 2)
 step_pca <- function(recipe,
                      ...,
                      role = "predictor",
@@ -112,6 +92,7 @@ step_pca <- function(recipe,
                      options = list(),
                      res = NULL,
                      prefix = "PC",
+                     keep_original_cols = FALSE,
                      skip = FALSE,
                      id = rand_id("pca")) {
 
@@ -132,6 +113,7 @@ step_pca <- function(recipe,
       options = options,
       res = res,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -140,7 +122,7 @@ step_pca <- function(recipe,
 
 step_pca_new <-
   function(terms, role, trained, num_comp, threshold, options, res,
-           prefix, skip, id) {
+           prefix,  keep_original_cols, skip, id) {
     step(
       subclass = "pca",
       terms = terms,
@@ -151,6 +133,7 @@ step_pca_new <-
       options = options,
       res = res,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -158,7 +141,7 @@ step_pca_new <-
 
 #' @export
 prep.step_pca <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -189,7 +172,7 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
     ## e.g. `sdev` etc.
 
   } else {
-    # fake a roation matrix so that the resolved names can be used for tidy()
+    # fake a rotation matrix so that the resolved names can be used for tidy()
     fake_matrix <- matrix(NA, nrow = length(col_names))
     rownames(fake_matrix) <- col_names
     prc_obj <- list(rotation = fake_matrix)
@@ -204,6 +187,7 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
     options = x$options,
     res = prc_obj,
     prefix = x$prefix,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -217,8 +201,11 @@ bake.step_pca <- function(object, new_data, ...) {
     comps <- comps[, 1:object$num_comp, drop = FALSE]
     comps <- check_name(comps, new_data, object)
     new_data <- bind_cols(new_data, as_tibble(comps))
-    new_data <-
-      new_data[, !(colnames(new_data) %in% pca_vars), drop = FALSE]
+    keep_original_cols <- get_keep_original_cols(object)
+
+    if (!keep_original_cols) {
+      new_data <- new_data[, !(colnames(new_data) %in% pca_vars), drop = FALSE]
+    }
   }
   as_tibble(new_data)
 }
@@ -289,8 +276,10 @@ pca_variances <- function(x) {
 
 
 
-#' @rdname step_pca
-#' @param x A `step_pca` object.
+#' @rdname tidy.recipe
+#' @param type For `step_pca`, either `"coef"` (for the variable loadings per
+#' component) or `"variance"` (how much variance does each component
+#' account for).
 #' @export
 tidy.step_pca <- function(x, type = "coef", ...) {
   if (!is_trained(x)) {
@@ -312,12 +301,15 @@ tidy.step_pca <- function(x, type = "coef", ...) {
 
 
 
-#' @rdname tunable.step
+#' @rdname tunable.recipe
 #' @export
 tunable.step_pca <- function(x, ...) {
   tibble::tibble(
-    name = "num_comp",
-    call_info = list(list(pkg = "dials", fun = "num_comp", range = c(1L, 4L))),
+    name = c("num_comp", "threshold"),
+    call_info = list(
+      list(pkg = "dials", fun = "num_comp", range = c(1L, 4L)),
+      list(pkg = "dials", fun = "threshold")
+    ),
     source = "recipe",
     component = "step_pca",
     component_id = x$id
