@@ -3,22 +3,15 @@
 #' `step_pls` creates a *specification* of a recipe step that will
 #'  convert numeric data into one or more new dimensions.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which variables will be
-#'  used to compute the dimensions. See [selections()] for more details. For the
-#'  `tidy` method, these are not currently used.
-#' @param role For model terms created by this step, what analysis role should
-#'  they be assigned?. By default, the function assumes that the new dimension
-#'  columns created by the original variables will be used as predictors in a
-#'  model.
 #' @param num_comp The number of pls dimensions to retain as new predictors.
 #'  If `num_comp` is greater than the number of columns or the number of
 #'  possible dimensions, a smaller value will be used.
 #' @param predictor_prop The maximum number of original predictors that can have
 #'  non-zero coefficients for each PLS component (via regularization).
-#' @param preserve A single logical: should the original predictor data be
-#' retained along with the new features?
+#' @param preserve Use `keep_original_cols` instead to specify whether the
+#'  original predictor data should be retained along with the new features.
 #' @param outcome When a single outcome is available, character
 #'  string or call to [dplyr::vars()] can be used to specify a single outcome
 #'  variable.
@@ -27,16 +20,8 @@
 #' arguments).
 #' @param res A list of results are stored here once this preprocessing step
 #'  has been trained by [prep.recipe()].
-#' @param prefix A character string that will be the prefix to the
-#'  resulting new variables. See notes below.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `components`, and `values`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept pls
-#' @concept projection_methods
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details PLS is a supervised version of principal component
 #'  analysis that requires the outcome data to compute
@@ -59,7 +44,7 @@
 #' proportion to determine the `keepX` parameter in `mixOmics::spls()` and
 #' `mixOmics::splsda()`. See the references in `mixOmics::spls()` for details.
 #'
-#' The `tidy()` method returns the coefficients that are usually defined as
+#' The [`tidy()`] method returns the coefficients that are usually defined as
 #'
 #' \deqn{W(P'W)^{-1}}
 #'
@@ -67,14 +52,15 @@
 #'
 #' When applied to data, these values are usually scaled by a column-specific
 #' norm. The `tidy()` method applies this same norm to the coefficients shown
-#' above.
+#' above. When you `tidy()` this step, a tibble with columns `terms` (the
+#' selectors or variables selected), `components`, and `values` is returned.
 #'
 #' @references
 #' \url{https://en.wikipedia.org/wiki/Partial_least_squares_regression}
 #'
 #' Rohart F, Gautier B, Singh A, Lê Cao K-A (2017) _mixOmics: An R package for
 #' 'omics feature selection and multiple data integration_. PLoS Comput Biol
-#' 13(11): e1005752. \url{https://doi.org/10.1371/journal.pcbi.1005752}
+#' 13(11): e1005752. \doi{10.1371/journal.pcbi.1005752}
 #' @examples
 #' # requires the Bioconductor mixOmics package
 #' data(biomass, package = "modeldata")
@@ -90,11 +76,11 @@
 #'
 #' dense_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
-#'   step_pls(all_predictors(), outcome = "HHV", num_comp = 3)
+#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3)
 #'
 #' sparse_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
-#'   step_pls(all_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4/5)
+#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4/5)
 #'
 #' ## -----------------------------------------------------------------------------
 #' ## PLS discriminant analysis
@@ -112,15 +98,12 @@
 #'
 #' dense_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
-#'   step_pls(all_predictors(), outcome = "class", num_comp = 5)
+#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5)
 #'
 #' sparse_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
-#'   step_pls(all_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
+#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
 #'
-#' @seealso [step_pca()], [step_kpca()], [step_ica()], [recipe()],
-#'  [prep.recipe()], [bake.recipe()]
-
 step_pls <-
   function(recipe,
            ...,
@@ -130,15 +113,25 @@ step_pls <-
            predictor_prop = 1,
            outcome = NULL,
            options = list(scale = TRUE),
-           preserve = FALSE,
+           preserve = deprecated(),
            res = NULL,
            prefix = "PLS",
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("pls")) {
     if (is.null(outcome)) {
       rlang::abort("`outcome` should select at least one column.")
     }
 
+    if (lifecycle::is_present(preserve)) {
+      lifecycle::deprecate_warn(
+        "0.1.16",
+        "step_pls(preserve = )",
+        "step_pls(keep_original_cols = )"
+      )
+      keep_original_cols <- preserve
+    }
+
     recipes_pkg_check(required_pkgs.step_pls())
 
     add_step(
@@ -151,9 +144,10 @@ step_pls <-
         predictor_prop = predictor_prop,
         outcome = outcome,
         options = options,
-        preserve = preserve,
+        preserve = keep_original_cols,
         res = res,
         prefix = prefix,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -162,7 +156,7 @@ step_pls <-
 
 step_pls_new <-
   function(terms, role, trained, num_comp, predictor_prop, outcome, options,
-           preserve, res, prefix, skip, id) {
+           preserve, res, prefix, keep_original_cols, skip, id) {
     step(
       subclass = "pls",
       terms = terms,
@@ -175,6 +169,7 @@ step_pls_new <-
       preserve = preserve,
       res = res,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -295,8 +290,8 @@ prop2int <- function(x, p) {
 
 #' @export
 prep.step_pls <- function(x, training, info = NULL, ...) {
-  x_names <- eval_select_recipes(x$terms, training, info)
-  y_names <- eval_select_recipes(x$outcome, training, info)
+  x_names <- recipes_eval_select(x$terms, training, info)
+  y_names <- recipes_eval_select(x$outcome, training, info)
 
   check_type(training[, x_names])
   if (length(y_names) > 1 ) {
@@ -334,6 +329,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     preserve = x$preserve,
     res = res,
     prefix = x$prefix,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -353,6 +349,7 @@ bake.step_pls <- function(object, new_data, ...) {
     comps <- check_name(comps, new_data, object)
 
     new_data <- bind_cols(new_data, as_tibble(comps))
+    keep_original_cols <- get_keep_original_cols(object)
 
     # Old pls never preserved original columns,
     # but didn't have the `preserve` option
@@ -360,7 +357,7 @@ bake.step_pls <- function(object, new_data, ...) {
       pls_vars <- rownames(object$res$projection)
       keep_vars <- !(colnames(new_data) %in% pls_vars)
       new_data <- new_data[, keep_vars, drop = FALSE]
-    } else if (!object$preserve) {
+    } else if (any(!object$preserve, !keep_original_cols)) {
       pls_vars <- names(object$res$mu)
       keep_vars <- !(colnames(new_data) %in% pls_vars)
       new_data <- new_data[, keep_vars, drop = FALSE]
@@ -385,8 +382,7 @@ print.step_pls <- function(x, width = max(20, options()$width - 35), ...) {
 }
 
 
-#' @rdname step_pls
-#' @param x A `step_pls` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_pls <- function(x, ...) {
   if (is_trained(x)) {
@@ -409,7 +405,7 @@ tidy.step_pls <- function(x, ...) {
 }
 
 
-#' @rdname tunable.step
+#' @rdname tunable.recipe
 #' @export
 tunable.step_pls <- function(x, ...) {
   tibble::tibble(
@@ -425,7 +421,7 @@ tunable.step_pls <- function(x, ...) {
 }
 
 
-#' @rdname required_pkgs.step
+#' @rdname required_pkgs.recipe
 #' @export
 required_pkgs.step_pls <- function(x, ...) {
   c("mixOmics")
