@@ -3,17 +3,9 @@
 #' `step_poly` creates a *specification* of a recipe
 #'  step that will create new columns that are basis expansions of
 #'  variables using orthogonal polynomials.
-
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details.  For the `tidy` method, these are not
-#'  currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
 #' @param objects A list of [stats::poly()] objects
 #'  created once the step has been trained.
 #' @param degree The polynomial degree (an integer).
@@ -21,21 +13,20 @@
 #'  which should not include `x`, `degree`, or `simple`. Note that
 #'  the option `raw = TRUE` will produce the regular polynomial
 #'  values (not orthogonalized).
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected) and `degree`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept basis_expansion
+#' @template step-return
+#' @family individual transformation steps
 #' @export
-#' @details `step_poly` can new features from a single
+#' @details `step_poly` can create new features from a single
 #'  variable that enable fitting routines to model this variable in
 #'  a nonlinear manner. The extent of the possible nonlinearity is
 #'  determined by the `degree` argument of
 #'  [stats::poly()]. The original variables are removed
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_poly_1` and so on.
+#'
+#'  When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  columns that will be affected) and `degree` is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -54,10 +45,6 @@
 #' expanded
 #'
 #' tidy(quadratic, number = 1)
-#' @seealso [step_ns()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
-
 step_poly <-
   function(recipe,
            ...,
@@ -130,7 +117,7 @@ poly_wrapper <- function(x, args) {
 
 #' @export
 prep.step_poly <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -162,7 +149,7 @@ bake.step_poly <- function(object, new_data, ...) {
     purrr::map(as_tibble) %>%
     purrr::map2_dfc(new_names, ~ setNames(.x, .y))
   new_data <- dplyr::bind_cols(new_data, poly_values)
-  new_data <- dplyr::select(new_data, -col_names)
+  new_data <- dplyr::select(new_data, -dplyr::all_of(col_names))
   new_data
 }
 
@@ -174,8 +161,7 @@ print.step_poly <-
     invisible(x)
   }
 
-#' @rdname step_poly
-#' @param x A `step_poly` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_poly <- function(x, ...) {
   if (is_trained(x)) {
@@ -189,7 +175,7 @@ tidy.step_poly <- function(x, ...) {
 }
 
 
-#' @rdname tunable.step
+#' @rdname tunable.recipe
 #' @export
 tunable.step_poly <- function(x, ...) {
   tibble::tibble(
