@@ -4,18 +4,14 @@
 #'  step that will create one or more ratios out of numeric
 #'  variables.
 #'
+#' @inheritParams step_date
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
 #' @param ... One or more selector functions to choose which
 #'  variables will be used in the *numerator* of the ratio.
 #'  When used with `denom_vars`, the dots indicate which
 #'  variables are used in the *denominator*. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For terms created by this step, what analysis role
-#'  should they be assigned?. By default, the function assumes that
-#'  the newly created ratios created by the original variables will
-#'  be used as predictors in a model.
+#'  [selections()] for more details.
 #' @param denom A call to `denom_vars` to specify which
 #'  variables are used in the denominator that can include specific
 #'  variable names separated by commas or different selectors (see
@@ -27,12 +23,10 @@
 #' @param columns The column names used in the ratios. This
 #'  argument is not populated until [prep.recipe()] is
 #'  executed.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `denom`.
-#' @keywords datagen
-#' @concept preprocessing
+#' @template step-return
+#' @details When you [`tidy()`] this step, a tibble with columns `terms` (the
+#'  selectors or variables selected) and `denom` is returned.
+#' @family multivariate transformation steps
 #' @export
 #' @examples
 #' library(recipes)
@@ -49,7 +43,7 @@
 #'
 #' ratio_recipe <- rec %>%
 #'   # all predictors over total
-#'   step_ratio(all_predictors(), denom = denom_vars(total)) %>%
+#'   step_ratio(all_numeric_predictors(), denom = denom_vars(total)) %>%
 #'   # get rid of the original predictors
 #'   step_rm(all_predictors(), -ends_with("total"))
 #'
@@ -67,6 +61,7 @@ step_ratio <-
            naming = function(numer, denom)
              make.names(paste(numer, denom, sep = "_o_")),
            columns = NULL,
+           keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("ratio")) {
     if (is_empty(denom))
@@ -85,6 +80,7 @@ step_ratio <-
         denom = denom,
         naming = naming,
         columns = columns,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -92,7 +88,8 @@ step_ratio <-
   }
 
 step_ratio_new <-
-  function(terms, role, trained, denom, naming, columns, skip, id) {
+  function(terms, role, trained, denom, naming, columns,
+           keep_original_cols, skip, id) {
     step(
       subclass = "ratio",
       terms = terms,
@@ -101,6 +98,7 @@ step_ratio_new <-
       denom = denom,
       naming = naming,
       columns = columns,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -110,8 +108,8 @@ step_ratio_new <-
 #' @export
 prep.step_ratio <- function(x, training, info = NULL, ...) {
   col_names <- expand.grid(
-    top = eval_select_recipes(x$terms, training, info),
-    bottom = eval_select_recipes(x$denom, training, info),
+    top = recipes_eval_select(x$terms, training, info),
+    bottom = recipes_eval_select(x$denom, training, info),
     stringsAsFactors = FALSE
   )
   col_names <- col_names[!(col_names$top == col_names$bottom), ]
@@ -130,6 +128,7 @@ prep.step_ratio <- function(x, training, info = NULL, ...) {
     denom = x$denom,
     naming = x$naming,
     columns = col_names,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -145,7 +144,14 @@ bake.step_ratio <- function(object, new_data, ...) {
   if (!is_tibble(res))
     res <- as_tibble(res)
 
+  keep_original_cols <- get_keep_original_cols(object)
   new_data <- bind_cols(new_data, res)
+
+  if (!keep_original_cols) {
+    union_cols <- union(object$columns$top, object$columns$bottom)
+    new_data <- new_data[, !(colnames(new_data) %in% union_cols), drop = FALSE]
+  }
+
   if (!is_tibble(new_data))
     new_data <- as_tibble(new_data)
   new_data
@@ -170,13 +176,12 @@ print.step_ratio <-
 #' @rdname step_ratio
 denom_vars <- function(...) quos(...)
 
-#' @rdname step_ratio
-#' @param x A `step_ratio` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_ratio <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$columns$top,
-                  denom = x$columns$bottom)
+    res <- tibble(terms = unname(x$columns$top),
+                  denom = unname(x$columns$bottom))
   } else {
     res <- tidyr::crossing(terms = sel2char(x$terms),
                            denom = sel2char(x$denom))
