@@ -4,32 +4,24 @@
 #'  that will remove variables based on their name, type, or role.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables that will be evaluated by the filtering bake. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param removals A character string that contains the names of
 #'  columns that should be removed. These values are not determined
 #'  until [prep.recipe()] is called.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be removed.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept variable_filters
+#' @template step-return
+#' @details When you [`tidy()`] this step, a tibble with column `terms` (the
+#'  columns that will be removed) is returned.
+#' @family variable filter steps
 #' @export
 #' @examples
 #' library(modeldata)
 #' data(biomass)
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
 #'
 #' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#'   data = biomass_tr
+#' )
 #'
 #' library(dplyr)
 #' smaller_set <- rec %>%
@@ -48,15 +40,17 @@ step_rm <- function(recipe,
                     removals = NULL,
                     skip = FALSE,
                     id = rand_id("rm")) {
-  add_step(recipe,
-           step_rm_new(
-             terms = ellipse_check(...),
-             role = role,
-             trained = trained,
-             removals = removals,
-             skip = skip,
-             id = id
-           ))
+  add_step(
+    recipe,
+    step_rm_new(
+      terms = ellipse_check(...),
+      role = role,
+      trained = trained,
+      removals = removals,
+      skip = skip,
+      id = id
+    )
+  )
 }
 
 step_rm_new <- function(terms, role, trained, removals, skip, id) {
@@ -73,7 +67,8 @@ step_rm_new <- function(terms, role, trained, removals, skip, id) {
 
 #' @export
 prep.step_rm <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
+
   step_rm_new(
     terms = x$terms,
     role = x$role,
@@ -86,8 +81,9 @@ prep.step_rm <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_rm <- function(object, new_data, ...) {
-  if (length(object$removals) > 0)
+  if (length(object$removals) > 0) {
     new_data <- new_data[, !(colnames(new_data) %in% object$removals)]
+  }
   as_tibble(new_data)
 }
 
@@ -97,21 +93,22 @@ print.step_rm <-
       if (length(x$removals) > 0) {
         cat("Variables removed ")
         cat(format_ch_vec(x$removals, width = width))
-      } else
+      } else {
         cat("No variables were removed")
+      }
     } else {
       cat("Delete terms ", sep = "")
       cat(format_selectors(x$terms, width = width))
     }
-    if (x$trained)
+    if (x$trained) {
       cat(" [trained]\n")
-    else
+    } else {
       cat("\n")
+    }
     invisible(x)
   }
 
 
-#' @rdname step_rm
-#' @param x A `step_rm` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_rm <- tidy_filter
