@@ -1,5 +1,3 @@
-
-
 #' @name selections
 #' @aliases selections
 #' @aliases selection
@@ -31,11 +29,11 @@
 #'    exclude variables (e.g. `-Murder`) and the set of selectors will
 #'    processed in order.
 #'   \item A leading exclusion in these arguments (e.g. `-Murder`)
-#'   has the effect of adding all variables to the list except the
-#'   excluded variable(s).
+#'   has the effect of adding *all* variables to the list except the
+#'   excluded variable(s), ignoring role information.
 #'   }
 #'
-#' Also, select helpers from the `tidyselect` package can also be used:
+#' Select helpers from the `tidyselect` package can also be used:
 #'   [tidyselect::starts_with()], [tidyselect::ends_with()],
 #'   [tidyselect::contains()], [tidyselect::matches()],
 #'   [tidyselect::num_range()], [tidyselect::everything()],
@@ -58,13 +56,17 @@
 #' case, using `matches("^PC")` will select all of the columns
 #' whose names start with "PC" *once those columns are created*.
 #'
-#' There are sets of recipes specific functions that can be used to select
+#' There are sets of recipes-specific functions that can be used to select
 #' variables based on their role or type: [has_role()] and
 #' [has_type()]. For convenience, there are also functions that are
-#' more specific: [all_numeric()], [all_nominal()],
-#' [all_predictors()], and [all_outcomes()]. These can be used in
-#' conjunction with the previous functions described for selecting
-#' variables using their names:
+#' more specific. The functions [all_numeric()] and [all_nominal()] select
+#' based on type, with nominal variables including both character and factor;
+#' the functions [all_predictors()] and [all_outcomes()] select based on role.
+#' The functions [all_numeric_predictors()] and [all_nominal_predictors()]
+#' select intersections of role and type. Any can be used in conjunction with
+#' the previous functions described for selecting variables using their names.
+#'
+#' A selection like this:
 #'
 #' \preformatted{
 #'   data(biomass)
@@ -72,7 +74,15 @@
 #'     step_center(all_numeric(), -all_outcomes())
 #' }
 #'
-#' This results in all the numeric predictors: carbon, hydrogen,
+#' is equivalent to:
+#'
+#' \preformatted{
+#'   data(biomass)
+#'   recipe(HHV ~ ., data = biomass) \%>\%
+#'     step_center(all_numeric_predictors())
+#' }
+#'
+#' Both result in all the numeric predictors: carbon, hydrogen,
 #' oxygen, nitrogen, and sulfur.
 #'
 #' If a role for a variable has not been defined, it will never be
@@ -92,70 +102,121 @@
 #' will not work.
 NULL
 
+# ------------------------------------------------------------------------------
+
+#' Evaluate a selection with tidyselect semantics specific to recipes
+#'
+#' @description
+#' `recipes_eval_select()` is a recipes specific variant of
+#' [tidyselect::eval_select()] enhanced with the ability to recognize recipes
+#' selectors, such as [all_numeric_predictors()]. See [selections]
+#' for more information about the unique recipes selectors.
+#'
+#' This is a developer tool that is only useful for creating new recipes steps.
+#'
+#' @inheritParams ellipsis::dots_empty
+#'
+#' @param quos A list of quosures describing the selection. This is generally
+#'   the `...` argument of your step function, captured with [ellipse_check()]
+#'   or [rlang::enquos()] and stored in the step object as the `terms` element.
+#'
+#' @param data A data frame to use as the context to evaluate the selection in.
+#'   This is generally the `training` data passed to the [prep()] method
+#'   of your step.
+#'
+#' @param info A data frame of term information describing each column's type
+#'   and role for use with the recipes selectors. This is generally the `info`
+#'   data passed to the [prep()] method of your step.
+#'
+#' @param allow_rename Should the renaming syntax `c(foo = bar)` be allowed?
+#'   This is rarely required, and is currently only used by [step_select()].
+#'   It is unlikely that your step will need renaming capabilities.
+#'
+#' @return
+#' A named character vector containing the evaluated selection. The names are
+#' always the same as the values, except when `allow_rename = TRUE`, in which
+#' case the names reflect the new names chosen by the user.
+#'
+#' @export
+#' @examples
+#' library(rlang)
+#' library(modeldata)
+#' data(scat)
+#'
+#' rec <- recipe(Species ~ ., data = scat)
+#'
+#' info <- summary(rec)
+#' info
+#'
+#' quos <- quos(all_numeric_predictors(), where(is.factor))
+#'
+#' recipes_eval_select(quos, scat, info)
+recipes_eval_select <- function(quos, data, info, ..., allow_rename = FALSE) {
+  ellipsis::check_dots_empty()
 
-eval_select_recipes <- function(quos, data, info) {
   # Maintain ordering between `data` column names and `info$variable` so
   # `eval_select()` and recipes selectors return compatible positions
   data_info <- tibble(variable = names(data))
   data_info <- dplyr::left_join(data_info, info, by = "variable")
 
-  nested_info <- nest_current_info(data_info)
+  nested_info <- tidyr::nest(data_info, data = -variable)
 
   local_current_info(nested_info)
 
   expr <- expr(c(!!!quos))
 
-  # FIXME: Ideally this is `FALSE`, but empty selections incorrectly throw an
+  # FIXME: Ideally this is `FALSE` for strict selection,
+  # but empty selections incorrectly throw an
   # error when this is false due to the following bug:
   # https://github.com/r-lib/tidyselect/issues/221
-  allow_rename <- TRUE
+  # Once it's fixed, remove this and pass allow_rename to
+  # tidyselect::eval_select().
+  allow_rename_compat <- TRUE
 
   sel <- tidyselect::eval_select(
     expr = expr,
     data = data,
-    allow_rename = allow_rename
+    allow_rename = allow_rename_compat
   )
 
   # Return names not positions, as these names are
   # used for both the training and test set and their positions
-  # may have changed. `sel` won't be named because when `allow_rename = FALSE`,
-  # `eval_select()` returns an unnamed vector.
+  # may have changed. If renaming is allowed, add the new names.
   out <- names(data)[sel]
+  names <- names(sel)
 
   # FIXME: Remove this check when the following issue is fixed,
-  # i.e. when we can use `allow_rename = FALSE`
+  # at that point, just pass `allow_rename` to `eval_select()` directly.
   # https://github.com/r-lib/tidyselect/issues/221
-  if (!identical(out, names(sel))) {
+  if (!allow_rename & !identical(out, names)) {
     abort("Can't rename variables in this context.")
   }
 
+  names(out) <- names
   out
 }
 
-nest_current_info <- function(info) {
-  # See https://tidyr.tidyverse.org/dev/articles/in-packages.html
-  if (tidyr_new_interface()) {
-    tidyr::nest(info, data = -variable)
-  } else {
-    tidyr::nest(info, -variable)
-  }
-}
-
 #' Role Selection
 #'
 #' @description
 #'
 #' `has_role()`, `all_predictors()`, and `all_outcomes()` can be used to
 #'  select variables in a formula that have certain roles.
-#'  Similarly, `has_type()`, `all_numeric()`, and `all_nominal()` are used
-#'  to select columns based on their data type.
 #'
-#'  See `?selections` for more details.
+#' Similarly, `has_type()`, `all_numeric()`, and `all_nominal()` are used to
+#'  select columns based on their data type. Nominal variables include both
+#'  character and factor.
+#'
+#' **In most cases**, the selectors `all_numeric_predictors()` and
+#'  `all_nominal_predictors()`, which select on role and type, will be the right
+#'  approach for users.
+#'
+#'  See [selections] for more details.
 #'
 #'  `current_info()` is an internal function.
 #'
-#'  All of these functions have have limited utility
-#'  outside of column selection in step functions.
+#'  All of these functions have have limited utility outside of column selection
+#'  in step functions.
 #'
 #' @param match A single character string for the query. Exact
 #'  matching is used (i.e. regular expressions won't work).
@@ -166,7 +227,6 @@ nest_current_info <- function(info) {
 #'
 #' `current_info()` returns an environment with objects `vars` and `data`.
 #'
-#' @keywords datagen
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -192,7 +252,8 @@ nest_current_info <- function(info) {
 #' @export
 has_role <- function(match = "predictor") {
   roles <- peek_roles()
-  lgl_matches <- purrr::map_lgl(roles, ~any(.x %in% match))
+  # roles is potentially a list columns so we unlist `.x` below.
+  lgl_matches <- purrr::map_lgl(roles, ~any(unlist(.x) %in% match))
   which(lgl_matches)
 }
 
@@ -202,6 +263,19 @@ all_predictors <- function() {
   has_role("predictor")
 }
 
+#' @export
+#' @rdname has_role
+all_numeric_predictors <- function() {
+  intersect(has_role("predictor"), has_type("numeric"))
+}
+
+#' @export
+#' @rdname has_role
+all_nominal_predictors <- function() {
+  intersect(has_role("predictor"), has_type("nominal"))
+}
+
+
 #' @export
 #' @rdname has_role
 all_outcomes <- function() {
@@ -261,123 +335,3 @@ local_current_info <- function(nested_info, frame = parent.frame()) {
 current_info <- function() {
   cur_info_env %||% rlang::abort("Variable context not set")
 }
-
-# ------------------------------------------------------------------------------
-# Old method for selection. This has been completely superseded by
-# `eval_select_recipes()`, and should no longer be used in recipes, but we
-# have exported it so we continue to support it here.
-
-# This flags formulas that are not allowed
-element_check <- function(x) {
-  funs <- fun_calls(x)
-  funs <- funs[!(funs %in% c("~", "+", "-"))]
-
-  # i.e. tidyselect::matches()
-  funs <- funs[!(funs %in% c("::", "tidyselect", "dplyr", "recipes"))]
-
-  name_selectors <- c(
-    "starts_with",
-    "ends_with",
-    "contains",
-    "matches",
-    "num_range",
-    "everything",
-    "one_of",
-    "all_of",
-    "any_of",
-    "c"
-  )
-  role_selectors <- c(
-    "has_role",
-    "all_predictors",
-    "all_outcomes"
-  )
-  type_selectors <- c(
-    "has_type",
-    "all_numeric",
-    "all_nominal"
-  )
-  selectors <- c(
-    name_selectors,
-    role_selectors,
-    type_selectors
-  )
-
-  not_good <- funs[!(funs %in% selectors)]
-
-  if (length(not_good) > 0) {
-    rlang::abort(paste0(
-      "Not all functions are allowed in step function selectors (e.g. ",
-      paste0("`", not_good, "`", collapse = ", "),
-      "). See ?selections."
-    ))
-  }
-
-  invisible(NULL)
-}
-
-#' Select Terms in a Step Function.
-#'
-#' This function bakes the step function selectors and might be
-#'  useful when creating custom steps.
-#'
-#' @param info A tibble with columns `variable`, `type`, `role`,
-#'  and `source` that represent the current state of the data. The
-#'  function [summary.recipe()] can be used to get this information
-#'  from a recipe.
-#' @param terms A list of formulas whose right-hand side contains
-#'  quoted expressions. See [rlang::quos()] for examples.
-#' @param empty_fun A function to execute when no terms are selected by the
-#'  step. The default function throws an error with a message.
-#' @keywords datagen
-#' @concept preprocessing
-#' @return A character string of column names or an error of there
-#'  are no selectors or if no variables are selected.
-#' @seealso [recipe()] [summary.recipe()]
-#'   [prep.recipe()]
-#' @export
-#' @examples
-#' library(rlang)
-#' library(modeldata)
-#' data(okc)
-#' rec <- recipe(~ ., data = okc)
-#' info <- summary(rec)
-#' terms_select(info = info, quos(all_predictors()))
-terms_select <- function(terms, info, empty_fun = abort_selection) {
-  # unique in case a variable has multiple roles
-  vars <- unique(info$variable)
-
-  if (is_empty(terms)) {
-    rlang::abort("At least one selector should be used")
-  }
-
-  ## check arguments against whitelist
-  lapply(terms, element_check)
-
-  # Set current_info so available to helpers
-
-  nested_info <- nest_current_info(info)
-
-  local_current_info(nested_info)
-
-  # `terms` might be a single call (like in step_interact()),
-  # or it could be a list of quosures.
-  # They have to be unquoted differently
-  if (is.call(terms)) {
-    sel <- with_handlers(
-      tidyselect::vars_select(vars, !! terms),
-      tidyselect_empty = empty_fun
-    )
-  } else {
-    sel <- with_handlers(
-      tidyselect::vars_select(vars, !!! terms),
-      tidyselect_empty = empty_fun
-    )
-  }
-
-  unname(sel)
-}
-
-abort_selection <- exiting(function(cnd) {
-  abort("No variables or terms were selected.")
-})
